<!DOCTYPE TS><TS>
<defaultcodec>iso8859-1</defaultcodec>
<context>
    <name>EditorToolBar</name>
    <message>
        <source>Cut (Ctrl + X)</source>
        <translation type="unfinished">Cut (Ctrl + X)</translation>
    </message>
    <message>
        <source>Copy (Ctrl + C)</source>
        <translation type="unfinished">Copy (Ctrl + C)</translation>
    </message>
    <message>
        <source>Paste (Ctrl + V)</source>
        <translation type="unfinished">Paste (Ctrl + V)</translation>
    </message>
    <message>
        <source>Undo (Ctrl + Z)</source>
        <translation type="unfinished">Undo (Ctrl + Z)</translation>
    </message>
    <message>
        <source>Redo (Ctrl + R)</source>
        <translation type="unfinished">Redo (Ctrl + R)</translation>
    </message>
    <message>
        <source>Power (Ctrl + 6)</source>
        <translation type="unfinished">Power (Ctrl + 6)</translation>
    </message>
    <message>
        <source>Parentheses (()</source>
        <translation type="unfinished">Parentheses (()</translation>
    </message>
    <message>
        <source>Absolute value (|)</source>
        <translation type="unfinished">Absolute value (|)</translation>
    </message>
    <message>
        <source>Fraction (Ctrl + /)</source>
        <translation type="unfinished">Fraction (Ctrl + /)</translation>
    </message>
    <message>
        <source>Root (Ctrl + 2)</source>
        <translation type="unfinished">Root (Ctrl + 2)</translation>
    </message>
</context>
<context>
    <name>G_measureObject</name>
    <message>
        <source>Distance {%1} {%2}</source>
        <translation type="unfinished">Distance {%1} {%2}</translation>
    </message>
    <message>
        <source>Circumference {%1}</source>
        <translation type="unfinished">Circumference {%1}</translation>
    </message>
    <message>
        <source>Length {%1}</source>
        <translation type="unfinished">Length {%1}</translation>
    </message>
    <message>
        <source>Radius {%1}</source>
        <translation type="unfinished">Radius {%1}</translation>
    </message>
    <message>
        <source>Arc Angle {%1}</source>
        <translation type="unfinished">Arc Angle {%1}</translation>
    </message>
    <message>
        <source>Angle {%1}{%2}{%3}</source>
        <translation type="unfinished">Angle {%1}{%2}{%3}</translation>
    </message>
    <message>
        <source>Ratio {%1}/{%2}</source>
        <translation type="unfinished">Ratio {%1}/{%2}</translation>
    </message>
    <message>
        <source>Slope {%1}</source>
        <translation type="unfinished">Slope {%1}</translation>
    </message>
    <message>
        <source>Area {%1}</source>
        <translation type="unfinished">Area {%1}</translation>
    </message>
</context>
<context>
    <name>G_ref</name>
    <message>
        <source>Point</source>
        <translation type="unfinished">Point</translation>
    </message>
    <message>
        <source>Segment</source>
        <translation type="unfinished">Segment</translation>
    </message>
    <message>
        <source>Ray</source>
        <translation type="unfinished">Ray</translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished">Line</translation>
    </message>
    <message>
        <source>Circle</source>
        <translation type="unfinished">Circle</translation>
    </message>
    <message>
        <source>Arc</source>
        <translation type="unfinished">Arc</translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation type="unfinished">Polygon</translation>
    </message>
    <message>
        <source>Circle Interior</source>
        <translation type="unfinished">Circle Interior</translation>
    </message>
    <message>
        <source>Arc Sector</source>
        <translation type="unfinished">Arc Sector</translation>
    </message>
    <message>
        <source>Arc Segment</source>
        <translation type="unfinished">Arc Segment</translation>
    </message>
    <message>
        <source>Locus</source>
        <translation type="unfinished">Locus</translation>
    </message>
    <message>
        <source>Measurement</source>
        <translation type="unfinished">Measurement</translation>
    </message>
    <message>
        <source>Calculation</source>
        <translation type="unfinished">Calculation</translation>
    </message>
    <message>
        <source>Annotation</source>
        <translation type="unfinished">Annotation</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">Unknown</translation>
    </message>
</context>
<context>
    <name>G_valueObject</name>
    <message>
        <source>undefined</source>
        <translation type="unfinished">undefined</translation>
    </message>
</context>
<context>
    <name>KSegCalculateEditor</name>
    <message>
        <source>Value is undefined</source>
        <translation type="unfinished">Value is undefined</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancel</translation>
    </message>
    <message>
        <source>Value is %1</source>
        <translation type="unfinished">Value is %1</translation>
    </message>
    <message>
        <source>Insert %1 %2</source>
        <comment>For example, &quot;Insert Measurement M1&quot;</comment>
        <translation type="unfinished">Insert %1 %2</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation type="unfinished">Ready</translation>
    </message>
</context>
<context>
    <name>KSegConstructionList</name>
    <message>
        <source>Loop on %1</source>
        <translation type="unfinished">Loop on %1</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">or</translation>
    </message>
    <message>
        <source>final</source>
        <translation type="unfinished">final</translation>
    </message>
    <message>
        <source>initial</source>
        <translation type="unfinished">initial</translation>
    </message>
    <message>
        <source>not constructed</source>
        <translation type="unfinished">not constructed</translation>
    </message>
    <message>
        <source>doesn&apos;t exist</source>
        <translation type="unfinished">doesn&apos;t exist</translation>
    </message>
    <message>
        <source>hidden</source>
        <translation type="unfinished">hidden</translation>
    </message>
    <message>
        <source>Given</source>
        <translation type="unfinished">Given</translation>
    </message>
    <message>
        <source>Final</source>
        <translation type="unfinished">Final</translation>
    </message>
    <message>
        <source>Initial</source>
        <translation type="unfinished">Initial</translation>
    </message>
    <message>
        <source>%1 is the translation of %2 by the vector from %3 to %4</source>
        <translation type="unfinished">%1 is the translation of %2 by the vector from %3 to %4</translation>
    </message>
    <message>
        <source>%1 is the rotation of %2 about %3 by angle %4</source>
        <translation type="unfinished">%1 is the rotation of %2 about %3 by angle %4</translation>
    </message>
    <message>
        <source>%1 is the image of %2 scaled about %3 by the ratio %4:%5</source>
        <translation type="unfinished">%1 is the image of %2 scaled about %3 by the ratio %4:%5</translation>
    </message>
    <message>
        <source>%1 is the image of %2 scaled about %3 by ratio %4</source>
        <translation type="unfinished">%1 is the image of %2 scaled about %3 by ratio %4</translation>
    </message>
    <message>
        <source>%1 is the reflection of %2 about %3</source>
        <translation type="unfinished">%1 is the reflection of %2 about %3</translation>
    </message>
    <message>
        <source>%1 is free</source>
        <translation type="unfinished">%1 is free</translation>
    </message>
    <message>
        <source>%1 is on %2</source>
        <translation type="unfinished">%1 is on %2</translation>
    </message>
    <message>
        <source>%1 is the intersection of %2 and %3</source>
        <translation type="unfinished">%1 is the intersection of %2 and %3</translation>
    </message>
    <message>
        <source>%1 is the 2nd intersection of %2 and %3</source>
        <translation type="unfinished">%1 is the 2nd intersection of %2 and %3</translation>
    </message>
    <message>
        <source>%1 is the midpoint of %2</source>
        <translation type="unfinished">%1 is the midpoint of %2</translation>
    </message>
    <message>
        <source>%1 has endpoints %2 and %3</source>
        <translation type="unfinished">%1 has endpoints %2 and %3</translation>
    </message>
    <message>
        <source>%1 is from %2 through %3</source>
        <translation type="unfinished">%1 is from %2 through %3</translation>
    </message>
    <message>
        <source>%1 bisects angle %2 %3 %4</source>
        <translation type="unfinished">%1 bisects angle %2 %3 %4</translation>
    </message>
    <message>
        <source>%1 is between %2 and %3</source>
        <translation type="unfinished">%1 is between %2 and %3</translation>
    </message>
    <message>
        <source>%1 is parallel to %2 through %3</source>
        <translation type="unfinished">%1 is parallel to %2 through %3</translation>
    </message>
    <message>
        <source>%1 is perpendicular to %2 through %3</source>
        <translation type="unfinished">%1 is perpendicular to %2 through %3</translation>
    </message>
    <message>
        <source>%1 is centered at %2 and passes through %3</source>
        <translation type="unfinished">%1 is centered at %2 and passes through %3</translation>
    </message>
    <message>
        <source>%1 has center at %2 and radius %3</source>
        <translation type="unfinished">%1 has center at %2 and radius %3</translation>
    </message>
    <message>
        <source>%1 passes through points %2, %3, and %4</source>
        <translation type="unfinished">%1 passes through points %2, %3, and %4</translation>
    </message>
    <message>
        <source>%1 is traced by %2, driven by %3</source>
        <translation type="unfinished">%1 is traced by %2, driven by %3</translation>
    </message>
    <message>
        <source>%1 involves %2</source>
        <translation type="unfinished">%1 involves %2</translation>
    </message>
    <message>
        <source>%1 is the distance between %2 and %3</source>
        <translation type="unfinished">%1 is the distance between %2 and %3</translation>
    </message>
    <message>
        <source>%1 is the length of %2</source>
        <translation type="unfinished">%1 is the length of %2</translation>
    </message>
    <message>
        <source>%1 is the angle of %2</source>
        <translation type="unfinished">%1 is the angle of %2</translation>
    </message>
    <message>
        <source>%1 is the angle between points %1, %2, and %3</source>
        <translation type="unfinished">%1 is the angle between points %1, %2, and %3</translation>
    </message>
    <message>
        <source>%1 is the ratio of %2 to %3</source>
        <translation type="unfinished">%1 is the ratio of %2 to %3</translation>
    </message>
    <message>
        <source>%1 is the slope of %2</source>
        <translation type="unfinished">%1 is the slope of %2</translation>
    </message>
    <message>
        <source>%1 is the area of %2</source>
        <translation type="unfinished">%1 is the area of %2</translation>
    </message>
    <message>
        <source>%1 is defined by %2</source>
        <translation type="unfinished">%1 is defined by %2</translation>
    </message>
    <message>
        <source>%1 has vertices at points %2</source>
        <translation type="unfinished">%1 has vertices at points %2</translation>
    </message>
    <message>
        <source>%1 is the radius of %2</source>
        <translation type="unfinished">%1 is the radius of %2</translation>
    </message>
    <message>
        <source>%1 is the endpoint of %2</source>
        <translation type="unfinished">%1 is the endpoint of %2</translation>
    </message>
    <message>
        <source>%1 is the 2nd endpoint of %2</source>
        <translation type="unfinished">%1 is the 2nd endpoint of %2</translation>
    </message>
    <message>
        <source>%1 is the center of %2</source>
        <translation type="unfinished">%1 is the center of %2</translation>
    </message>
</context>
<context>
    <name>KSegDocument</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancel</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
</context>
<context>
    <name>KSegPreferencesDialog</name>
    <message>
        <source>KSEG Preferences</source>
        <translation type="unfinished">KSEG Preferences</translation>
    </message>
    <message>
        <source>Background Color</source>
        <translation type="unfinished">Background Color</translation>
    </message>
    <message>
        <source>Default Foreground Color</source>
        <translation type="unfinished">Default Foreground Color</translation>
    </message>
    <message>
        <source>Selection Display</source>
        <translation type="unfinished">Selection Display</translation>
    </message>
    <message>
        <source>Border Selection</source>
        <translation type="unfinished">Border Selection</translation>
    </message>
    <message>
        <source>Blinking Selection</source>
        <translation type="unfinished">Blinking Selection</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancel</translation>
    </message>
</context>
<context>
    <name>KSegRecursionDialog</name>
    <message>
        <source>Enter recursion depth:</source>
        <translation type="unfinished">Enter recursion depth:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancel</translation>
    </message>
    <message>
        <source>Will produce too many objects.</source>
        <translation type="unfinished">Will produce too many objects.</translation>
    </message>
    <message>
        <source>Will produce %1 objects.</source>
        <translation type="unfinished">Will produce %1 objects.</translation>
    </message>
</context>
<context>
    <name>KSegSampleChangeDialog</name>
    <message>
        <source>Samples in locus:</source>
        <translation type="unfinished">Samples in locus:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancel</translation>
    </message>
</context>
<context>
    <name>KSegSelectionGroupDialog</name>
    <message>
        <source>Select</source>
        <translation type="unfinished">Select</translation>
    </message>
    <message>
        <source>Deselect</source>
        <translation type="unfinished">Deselect</translation>
    </message>
    <message>
        <source>New Group</source>
        <translation type="unfinished">New Group</translation>
    </message>
    <message>
        <source>Delete Group</source>
        <translation type="unfinished">Delete Group</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished">Close</translation>
    </message>
    <message>
        <source>Affect
Invisible
Items</source>
        <translation type="unfinished">Affect
Invisible
Items</translation>
    </message>
    <message>
        <source>Hold SHIFT and click to add to current selection</source>
        <translation type="unfinished">Hold SHIFT and click to add to current selection</translation>
    </message>
    <message>
        <source>Whether the &quot;All &lt;Type&gt;&quot; groups also (de)select invisible objects</source>
        <translation type="unfinished">Whether the &quot;All &lt;Type&gt;&quot; groups also (de)select invisible objects</translation>
    </message>
    <message>
        <source>All Points</source>
        <translation type="unfinished">All Points</translation>
    </message>
    <message>
        <source>All Segments</source>
        <translation type="unfinished">All Segments</translation>
    </message>
    <message>
        <source>All Rays</source>
        <translation type="unfinished">All Rays</translation>
    </message>
    <message>
        <source>All Lines</source>
        <translation type="unfinished">All Lines</translation>
    </message>
    <message>
        <source>All Circles</source>
        <translation type="unfinished">All Circles</translation>
    </message>
    <message>
        <source>All Arcs</source>
        <translation type="unfinished">All Arcs</translation>
    </message>
    <message>
        <source>All Polygons</source>
        <translation type="unfinished">All Polygons</translation>
    </message>
    <message>
        <source>All Circle Interiors</source>
        <translation type="unfinished">All Circle Interiors</translation>
    </message>
    <message>
        <source>All Arc Sectors</source>
        <translation type="unfinished">All Arc Sectors</translation>
    </message>
    <message>
        <source>All Arc Segments</source>
        <translation type="unfinished">All Arc Segments</translation>
    </message>
    <message>
        <source>All Loci</source>
        <translation type="unfinished">All Loci</translation>
    </message>
    <message>
        <source>All Measurements</source>
        <translation type="unfinished">All Measurements</translation>
    </message>
    <message>
        <source>All Calculations</source>
        <translation type="unfinished">All Calculations</translation>
    </message>
    <message>
        <source>Enter new group name:</source>
        <translation type="unfinished">Enter new group name:</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected group(s)?</source>
        <translation type="unfinished">Are you sure you want to delete the selected group(s)?</translation>
    </message>
</context>
<context>
    <name>KSegView</name>
    <message>
        <source>Untitled</source>
        <translation type="unfinished">Untitled</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation type="unfinished">Ready</translation>
    </message>
    <message>
        <source>Move label of %1 %2</source>
        <comment>E.g. &quot;Move label of Point P1&quot;</comment>
        <translation type="unfinished">Move label of %1 %2</translation>
    </message>
    <message>
        <source>Select %1 %2</source>
        <translation type="unfinished">Select %1 %2</translation>
    </message>
    <message>
        <source>Deselect %1 %2</source>
        <translation type="unfinished">Deselect %1 %2</translation>
    </message>
    <message>
        <source>Also select %1 %2</source>
        <translation type="unfinished">Also select %1 %2</translation>
    </message>
    <message>
        <source>Move Selected Objects</source>
        <translation type="unfinished">Move Selected Objects</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to be free</source>
        <translation type="unfinished">Reconstrain %1 %2 to be free</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to %3 %4</source>
        <comment>E.g., &quot;Reconstrain Point P1 to Line l1&quot;</comment>
        <translation type="unfinished">Reconstrain %1 %2 to %3 %4</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to the intersection of %3 %4 and %5 %6</source>
        <translation type="unfinished">Reconstrain %1 %2 to the intersection of %3 %4 and %5 %6</translation>
    </message>
    <message>
        <source>Pan</source>
        <translation type="unfinished">Pan</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished">Zoom</translation>
    </message>
</context>
<context>
    <name>KSegWindow</name>
    <message>
        <source>kseg: Untitled</source>
        <translation type="unfinished">kseg: Untitled</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;File</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Edit</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;New</translation>
    </message>
    <message>
        <source>Meas&amp;ure</source>
        <translation type="unfinished">Meas&amp;ure</translation>
    </message>
    <message>
        <source>&amp;Transform</source>
        <translation type="unfinished">&amp;Transform</translation>
    </message>
    <message>
        <source>Pla&amp;y</source>
        <translation type="unfinished">Pla&amp;y</translation>
    </message>
    <message>
        <source>Const&amp;ruction</source>
        <translation type="unfinished">Const&amp;ruction</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Help</translation>
    </message>
    <message>
        <source>&amp;New Sketch</source>
        <translation type="unfinished">&amp;New Sketch</translation>
    </message>
    <message>
        <source>Ne&amp;w Construction</source>
        <translation type="unfinished">Ne&amp;w Construction</translation>
    </message>
    <message>
        <source>New &amp;View</source>
        <translation type="unfinished">New &amp;View</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation type="unfinished">&amp;Open...</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="unfinished">&amp;Save</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation type="unfinished">Save &amp;As...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation type="unfinished">&amp;Print...</translation>
    </message>
    <message>
        <source>Choose &amp;Language...</source>
        <translation type="unfinished">Choose &amp;Language...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Close</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished">&amp;Quit</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation type="unfinished">&amp;Undo</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation type="unfinished">&amp;Redo</translation>
    </message>
    <message>
        <source>&amp;Delete Objects</source>
        <translation type="unfinished">&amp;Delete Objects</translation>
    </message>
    <message>
        <source>Toggle &amp;Label</source>
        <translation type="unfinished">Toggle &amp;Label</translation>
    </message>
    <message>
        <source>Hide Label</source>
        <translation type="unfinished">Hide Label</translation>
    </message>
    <message>
        <source>Show Label</source>
        <translation type="unfinished">Show Label</translation>
    </message>
    <message>
        <source>Change La&amp;bel...</source>
        <translation type="unfinished">Change La&amp;bel...</translation>
    </message>
    <message>
        <source>&amp;Hide Objects</source>
        <translation type="unfinished">&amp;Hide Objects</translation>
    </message>
    <message>
        <source>&amp;Unhide All</source>
        <translation type="unfinished">&amp;Unhide All</translation>
    </message>
    <message>
        <source>&amp;Color</source>
        <translation type="unfinished">&amp;Color</translation>
    </message>
    <message>
        <source>Line &amp;Style</source>
        <translation type="unfinished">Line &amp;Style</translation>
    </message>
    <message>
        <source>&amp;Point Style</source>
        <translation type="unfinished">&amp;Point Style</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation type="unfinished">&amp;Font</translation>
    </message>
    <message>
        <source>Change &amp;Number of Samples...</source>
        <translation type="unfinished">Change &amp;Number of Samples...</translation>
    </message>
    <message>
        <source>&amp;Other...</source>
        <translation type="unfinished">&amp;Other...</translation>
    </message>
    <message>
        <source>&amp;Font...</source>
        <translation type="unfinished">&amp;Font...</translation>
    </message>
    <message>
        <source>&amp;Intersection Point</source>
        <translation type="unfinished">&amp;Intersection Point</translation>
    </message>
    <message>
        <source>&amp;Segment</source>
        <translation type="unfinished">&amp;Segment</translation>
    </message>
    <message>
        <source>&amp;Midpoint</source>
        <translation type="unfinished">&amp;Midpoint</translation>
    </message>
    <message>
        <source>&amp;Ray</source>
        <translation type="unfinished">&amp;Ray</translation>
    </message>
    <message>
        <source>&amp;Line</source>
        <translation type="unfinished">&amp;Line</translation>
    </message>
    <message>
        <source>&amp;Perpendicular Line</source>
        <translation type="unfinished">&amp;Perpendicular Line</translation>
    </message>
    <message>
        <source>&amp;Circle By Center And Point</source>
        <translation type="unfinished">&amp;Circle By Center And Point</translation>
    </message>
    <message>
        <source>&amp;Arc By Three Points</source>
        <translation type="unfinished">&amp;Arc By Three Points</translation>
    </message>
    <message>
        <source>Angle &amp;Bisector</source>
        <translation type="unfinished">Angle &amp;Bisector</translation>
    </message>
    <message>
        <source>L&amp;ocus</source>
        <translation type="unfinished">L&amp;ocus</translation>
    </message>
    <message>
        <source>Poly&amp;gon</source>
        <translation type="unfinished">Poly&amp;gon</translation>
    </message>
    <message>
        <source>Arc S&amp;ector</source>
        <translation type="unfinished">Arc S&amp;ector</translation>
    </message>
    <message>
        <source>Arc Se&amp;gment</source>
        <translation type="unfinished">Arc Se&amp;gment</translation>
    </message>
    <message>
        <source>Circle I&amp;nterior</source>
        <translation type="unfinished">Circle I&amp;nterior</translation>
    </message>
    <message>
        <source>&amp;Distance</source>
        <translation type="unfinished">&amp;Distance</translation>
    </message>
    <message>
        <source>&amp;Length</source>
        <translation type="unfinished">&amp;Length</translation>
    </message>
    <message>
        <source>&amp;Radius</source>
        <translation type="unfinished">&amp;Radius</translation>
    </message>
    <message>
        <source>&amp;Angle</source>
        <translation type="unfinished">&amp;Angle</translation>
    </message>
    <message>
        <source>Ra&amp;tio</source>
        <translation type="unfinished">Ra&amp;tio</translation>
    </message>
    <message>
        <source>&amp;Slope</source>
        <translation type="unfinished">&amp;Slope</translation>
    </message>
    <message>
        <source>Ar&amp;ea</source>
        <translation type="unfinished">Ar&amp;ea</translation>
    </message>
    <message>
        <source>&amp;Calculate...</source>
        <translation type="unfinished">&amp;Calculate...</translation>
    </message>
    <message>
        <source>Choose &amp;Vector</source>
        <translation type="unfinished">Choose &amp;Vector</translation>
    </message>
    <message>
        <source>Choose &amp;Mirror</source>
        <translation type="unfinished">Choose &amp;Mirror</translation>
    </message>
    <message>
        <source>Choose &amp;Center</source>
        <translation type="unfinished">Choose &amp;Center</translation>
    </message>
    <message>
        <source>Choose &amp;Angle</source>
        <translation type="unfinished">Choose &amp;Angle</translation>
    </message>
    <message>
        <source>Choose Rati&amp;o</source>
        <translation type="unfinished">Choose Rati&amp;o</translation>
    </message>
    <message>
        <source>C&amp;lear Chosen</source>
        <translation type="unfinished">C&amp;lear Chosen</translation>
    </message>
    <message>
        <source>&amp;Translate</source>
        <translation type="unfinished">&amp;Translate</translation>
    </message>
    <message>
        <source>R&amp;eflect</source>
        <translation type="unfinished">R&amp;eflect</translation>
    </message>
    <message>
        <source>&amp;Scale</source>
        <translation type="unfinished">&amp;Scale</translation>
    </message>
    <message>
        <source>&amp;Rotate</source>
        <translation type="unfinished">&amp;Rotate</translation>
    </message>
    <message>
        <source>Make &amp;Normal</source>
        <translation type="unfinished">Make &amp;Normal</translation>
    </message>
    <message>
        <source>Make &amp;Given</source>
        <translation type="unfinished">Make &amp;Given</translation>
    </message>
    <message>
        <source>Make &amp;Final</source>
        <translation type="unfinished">Make &amp;Final</translation>
    </message>
    <message>
        <source>Make &amp;Initial</source>
        <translation type="unfinished">Make &amp;Initial</translation>
    </message>
    <message>
        <source>&amp;Recurse</source>
        <translation type="unfinished">&amp;Recurse</translation>
    </message>
    <message>
        <source>&amp;Quick Play</source>
        <translation type="unfinished">&amp;Quick Play</translation>
    </message>
    <message>
        <source>&amp;About...</source>
        <translation type="unfinished">&amp;About...</translation>
    </message>
    <message>
        <source>&amp;Circumference</source>
        <translation type="unfinished">&amp;Circumference</translation>
    </message>
    <message>
        <source>Arc &amp;Length</source>
        <translation type="unfinished">Arc &amp;Length</translation>
    </message>
    <message>
        <source>Toggle &amp;Labels</source>
        <translation type="unfinished">Toggle &amp;Labels</translation>
    </message>
    <message>
        <source>Hide Labels</source>
        <translation type="unfinished">Hide Labels</translation>
    </message>
    <message>
        <source>Show Labels</source>
        <translation type="unfinished">Show Labels</translation>
    </message>
    <message>
        <source>&amp;Segments</source>
        <translation type="unfinished">&amp;Segments</translation>
    </message>
    <message>
        <source>&amp;Rays</source>
        <translation type="unfinished">&amp;Rays</translation>
    </message>
    <message>
        <source>&amp;Midpoints</source>
        <translation type="unfinished">&amp;Midpoints</translation>
    </message>
    <message>
        <source>&amp;Intersection Points</source>
        <translation type="unfinished">&amp;Intersection Points</translation>
    </message>
    <message>
        <source>&amp;Circle By Center And Radius</source>
        <translation type="unfinished">&amp;Circle By Center And Radius</translation>
    </message>
    <message>
        <source>&amp;Lines</source>
        <translation type="unfinished">&amp;Lines</translation>
    </message>
    <message>
        <source>Parallel &amp;Lines</source>
        <translation type="unfinished">Parallel &amp;Lines</translation>
    </message>
    <message>
        <source>Parallel &amp;Line</source>
        <translation type="unfinished">Parallel &amp;Line</translation>
    </message>
    <message>
        <source>&amp;Perpendicular Lines</source>
        <translation type="unfinished">&amp;Perpendicular Lines</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation type="unfinished">Untitled</translation>
    </message>
    <message>
        <source>&amp;Change Directory...</source>
        <translation type="unfinished">&amp;Change Directory...</translation>
    </message>
    <message>
        <source>No Constructions</source>
        <translation type="unfinished">No Constructions</translation>
    </message>
    <message>
        <source>Save?</source>
        <translation type="unfinished">Save?</translation>
    </message>
    <message>
        <source>Would you like to save your changes?</source>
        <translation type="unfinished">Would you like to save your changes?</translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation type="unfinished">File Not Found</translation>
    </message>
    <message>
        <source>Sorry, I am afraid that file %1 does not exist.</source>
        <translation type="unfinished">Sorry, I am afraid that file %1 does not exist.</translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation type="unfinished">Invalid file</translation>
    </message>
    <message>
        <source>The file %1 does not look like a valid KSEG file.</source>
        <translation type="unfinished">The file %1 does not look like a valid KSEG file.</translation>
    </message>
    <message>
        <source>Language Change</source>
        <translation type="unfinished">Language Change</translation>
    </message>
    <message>
        <source>You will need to restart KSEG for the language change to fully take effect.</source>
        <translation type="unfinished">You will need to restart KSEG for the language change to fully take effect.</translation>
    </message>
    <message>
        <source>About KSEG</source>
        <translation type="unfinished">About KSEG</translation>
    </message>
    <message>
        <source>&amp;Delete Object</source>
        <translation type="unfinished">&amp;Delete Object</translation>
    </message>
    <message>
        <source>&amp;Hide Object</source>
        <translation type="unfinished">&amp;Hide Object</translation>
    </message>
    <message>
        <source>Pr&amp;eferences...</source>
        <translation type="unfinished">Pr&amp;eferences...</translation>
    </message>
    <message>
        <source>KSEG v%1
Copyright (C) %2 Ilya Baran
http://www.mit.edu/~ibaran
ibaran@mit.edu</source>
        <translation type="unfinished">KSEG v%1
Copyright (C) %2 Ilya Baran
http://www.mit.edu/~ibaran
ibaran@mit.edu</translation>
    </message>
    <message>
        <source>Open In Current Window...</source>
        <translation type="unfinished">Open In Current Window...</translation>
    </message>
    <message>
        <source>Copy As Construction</source>
        <translation type="unfinished">Copy As Construction</translation>
    </message>
    <message>
        <source>Selection &amp;Groups...</source>
        <translation type="unfinished">Selection &amp;Groups...</translation>
    </message>
    <message>
        <source>&amp;Zoom</source>
        <translation type="unfinished">&amp;Zoom</translation>
    </message>
    <message>
        <source>&amp;Pan</source>
        <translation type="unfinished">&amp;Pan</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="unfinished">&amp;View</translation>
    </message>
    <message>
        <source>Zoom To &amp;Fit</source>
        <translation type="unfinished">Zoom To &amp;Fit</translation>
    </message>
    <message>
        <source>&amp;Original Zoom (100%)</source>
        <translation type="unfinished">&amp;Original Zoom (100%)</translation>
    </message>
    <message>
        <source>E&amp;xport To Image...</source>
        <translation type="unfinished">E&amp;xport To Image...</translation>
    </message>
    <message>
        <source>Endpoints</source>
        <translation type="unfinished">Endpoints</translation>
    </message>
    <message>
        <source>Center Point</source>
        <translation type="unfinished">Center Point</translation>
    </message>
    <message>
        <source>Endpoint</source>
        <translation type="unfinished">Endpoint</translation>
    </message>
    <message>
        <source>Zoom:</source>
        <translation type="unfinished">Zoom:</translation>
    </message>
    <message>
        <source>Choose the File Format:</source>
        <translation type="unfinished">Choose the File Format:</translation>
    </message>
    <message>
        <source>High Quality Image</source>
        <translation type="unfinished">High Quality Image</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Exporting, Please wait...</source>
        <translation type="unfinished">Exporting, Please wait...</translation>
    </message>
</context>
<context>
    <name>MatrixDialog</name>
    <message>
        <source>Rows:</source>
        <translation type="unfinished">Rows:</translation>
    </message>
    <message>
        <source>Columns:</source>
        <translation type="unfinished">Columns:</translation>
    </message>
    <message>
        <source>Zero-Fill</source>
        <translation type="unfinished">Zero-Fill</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancel</translation>
    </message>
</context>
</TS>
